From: "Lorenzo Stoakes (ARM)" <ljs@kernel.org>
To: Kees Cook <kees@kernel.org>
Cc: "Linus Torvalds" <torvalds@linux-foundation.org>,
"Nathan Chancellor" <nathan@kernel.org>,
"Nicolas Schier" <nsc@kernel.org>,
"Nick Desaulniers" <ndesaulniers@google.com>,
"Bill Wendling" <morbo@google.com>,
"Justin Stitt" <justinstitt@google.com>,
"Masahiro Yamada" <masahiroy@kernel.org>,
"Alexey Gladkov" <legion@kernel.org>,
"Thomas Gleixner" <tglx@kernel.org>,
"Ingo Molnar" <mingo@redhat.com>,
"Borislav Petkov" <bp@alien8.de>,
"Dave Hansen" <dave.hansen@linux.intel.com>,
x86@kernel.org, "H. Peter Anvin" <hpa@zytor.com>,
"Paul Walmsley" <pjw@kernel.org>,
"Palmer Dabbelt" <palmer@dabbelt.com>,
"Albert Ou" <aou@eecs.berkeley.edu>,
"Alexandre Ghiti" <alex@ghiti.fr>,
"Arnd Bergmann" <arnd@arndb.de>,
"Catalin Marinas" <catalin.marinas@arm.com>,
"Will Deacon" <will@kernel.org>,
"Mark Rutland" <mark.rutland@arm.com>,
"Ard Biesheuvel" <ardb@kernel.org>,
"Ilias Apalodimas" <ilias.apalodimas@linaro.org>,
"Josh Poimboeuf" <jpoimboe@kernel.org>,
"Peter Zijlstra" <peterz@infradead.org>,
"Miguel Ojeda" <ojeda@kernel.org>,
"Boqun Feng" <boqun@kernel.org>, "Gary Guo" <gary@garyguo.net>,
"Björn Roy Baron" <bjorn3_gh@protonmail.com>,
"Benno Lossin" <lossin@kernel.org>,
"Andreas Hindborg" <a.hindborg@kernel.org>,
"Alice Ryhl" <aliceryhl@google.com>,
"Trevor Gross" <tmgross@umich.edu>,
"Danilo Krummrich" <dakr@kernel.org>,
"Daniel Almeida" <daniel.almeida@collabora.com>,
"Tamir Duberstein" <tamird@kernel.org>,
"Alexandre Courbot" <acourbot@nvidia.com>,
"Onur Özkan" <work@onurozkan.dev>,
"Jonathan Corbet" <corbet@lwn.net>,
"Randy Dunlap" <rdunlap@infradead.org>,
"Gustavo A. R. Silva" <gustavoars@kernel.org>,
linux-kbuild@vger.kernel.org, linux-kernel@vger.kernel.org,
llvm@lists.linux.dev, linux-riscv@lists.infradead.org,
linux-arch@vger.kernel.org, linux-arm-kernel@lists.infradead.org,
linux-efi@vger.kernel.org, rust-for-linux@vger.kernel.org,
linux-doc@vger.kernel.org, "Jens Axboe" <axboe@kernel.dk>,
linux-hardening@vger.kernel.org
Subject: Re: [PATCH v2 00/21] kbuild: significantly speed up kernel builds
Date: Mon, 14 Sep 2026 19:25:28 +0100 [thread overview]
Message-ID: <aqg5nvRy9nuvC78L@gremlin> (raw)
In-Reply-To: <202609140833.88C0E16E50@keescook>
On Mon, Sep 14, 2026 at 08:41:39AM -0700, Kees Cook wrote:
> On Mon, Sep 14, 2026 at 10:21:59AM +0100, Lorenzo Stoakes (ARM) wrote:
> > This series makes allmodconfig builds up to 36% faster, ...
>
> This is very nice!
Thanks :)
>
> > incremental builds
> > up to ~70% faster, and noop builds up to ~90% faster.
>
> Some of the changes for this seem to add complexity that I'm not sure
> is balanced against the gain? I am still looking through the series,
> though, maybe I'll change my opinion. ;)
Well, I aggressively stripped all the commits that had a bad RoI on that.
And a lot of these are additive over 21 commits.
So, unfortunately, hacking away at what seem like low cost commits will eat
away at the overall result.
I really did work hard to cut the fat where I could, believe me going
through what remained and a. figuring out what it did, b. rewriting a lot
of the code and c. rewriting commit messages (ahem ;) was NOT fun :)
So I was happy to swing the axe as it saved me in terms of what little
sanity remains ;)
>
> > == allmodconfig FULL build ==
>
> Did you try Clang CONFIG_LTO=y builds?
I tried a CONFIG_LTO_CLANG_THIN in order to check that the *.mod.S stuff
worked correctly, all working correctly.
I can try to get some profiling numbers for thin and full if you want?
>
> > == LLM usage ==
> > [...]
> > I extensively audited and rewrote a lot of it, and heavily edited commit
> > messages, the cover letter and comments.
>
> I feel like the commit logs still need a lot of work. The LLM verbosity
> problem appears in many of them, for example spending 80% of the commit
Well I rewrote the majority of them, so this is a stinging critique of my
commit message writing I guess :)
> log describing every step of some process as background before getting
> to the actual change. I think a human writing this would be much more
> terse about the background. I have, however, been known to be too terse
> in my own commit logs. :P
I mean no, I did write nearly all of them. So I guess err... yeah :)
The testing results and perf numbers are generated and maybe I missed some
bits but generally this is so.
Anyway, I am known to be critical on-list on occasion, so if you dish it
out you have to take it - if you point out specific commit messages that
need work then I can try to put commit msgs on a diet :)
(N.B. I have had feedback like that on a fair few human-written commit
messages of mine lately so there might be some validity to that ;)
>
> > [...]
> > Nothing too controversial was included. There are further improvements that
> > could be made, but they would either by very invasive (large scale C header
> > changes) or generate diminishing returns.
>
> One area I think might solved via an LLM is the 3-pass kallsyms stuff.
> If we could get a deterministic kallsyms build in 1 pass, that would be
> very nice. A lot of people have tried, but it has eluded upstreaming.
"going from three passes to one would save around 8s on an allmodconfig
build and 2 to 3s on defconfig, out of tails that are currently roughly 25s
and 8s." says the LLM :) so that actually does seem worthwhile.
But I think best as a follow up?
I'd like to land the really low-hanging fruit before maybe digging in to
what else we can cut out :)
>
> -Kees
>
> --
> Kees Cook
--
Cheers, Lorenzo
WARNING: multiple messages have this Message-ID (diff)
From: "Lorenzo Stoakes (ARM)" <ljs@kernel.org>
To: Kees Cook <kees@kernel.org>
Cc: "Linus Torvalds" <torvalds@linux-foundation.org>,
"Nathan Chancellor" <nathan@kernel.org>,
"Nicolas Schier" <nsc@kernel.org>,
"Nick Desaulniers" <ndesaulniers@google.com>,
"Bill Wendling" <morbo@google.com>,
"Justin Stitt" <justinstitt@google.com>,
"Masahiro Yamada" <masahiroy@kernel.org>,
"Alexey Gladkov" <legion@kernel.org>,
"Thomas Gleixner" <tglx@kernel.org>,
"Ingo Molnar" <mingo@redhat.com>,
"Borislav Petkov" <bp@alien8.de>,
"Dave Hansen" <dave.hansen@linux.intel.com>,
x86@kernel.org, "H. Peter Anvin" <hpa@zytor.com>,
"Paul Walmsley" <pjw@kernel.org>,
"Palmer Dabbelt" <palmer@dabbelt.com>,
"Albert Ou" <aou@eecs.berkeley.edu>,
"Alexandre Ghiti" <alex@ghiti.fr>,
"Arnd Bergmann" <arnd@arndb.de>,
"Catalin Marinas" <catalin.marinas@arm.com>,
"Will Deacon" <will@kernel.org>,
"Mark Rutland" <mark.rutland@arm.com>,
"Ard Biesheuvel" <ardb@kernel.org>,
"Ilias Apalodimas" <ilias.apalodimas@linaro.org>,
"Josh Poimboeuf" <jpoimboe@kernel.org>,
"Peter Zijlstra" <peterz@infradead.org>,
"Miguel Ojeda" <ojeda@kernel.org>,
"Boqun Feng" <boqun@kernel.org>, "Gary Guo" <gary@garyguo.net>,
"Björn Roy Baron" <bjorn3_gh@protonmail.com>,
"Benno Lossin" <lossin@kernel.org>,
"Andreas Hindborg" <a.hindborg@kernel.org>,
"Alice Ryhl" <aliceryhl@google.com>,
"Trevor Gross" <tmgross@umich.edu>,
"Danilo Krummrich" <dakr@kernel.org>,
"Daniel Almeida" <daniel.almeida@collabora.com>,
"Tamir Duberstein" <tamird@kernel.org>,
"Alexandre Courbot" <acourbot@nvidia.com>,
"Onur Özkan" <work@onurozkan.dev>,
"Jonathan Corbet" <corbet@lwn.net>,
"Randy Dunlap" <rdunlap@infradead.org>,
"Gustavo A. R. Silva" <gustavoars@kernel.org>,
linux-kbuild@vger.kernel.org, linux-kernel@vger.kernel.org,
llvm@lists.linux.dev, linux-riscv@lists.infradead.org,
linux-arch@vger.kernel.org, linux-arm-kernel@lists.infradead.org,
linux-efi@vger.kernel.org, rust-for-linux@vger.kernel.org,
linux-doc@vger.kernel.org, "Jens Axboe" <axboe@kernel.dk>,
linux-hardening@vger.kernel.org
Subject: Re: [PATCH v2 00/21] kbuild: significantly speed up kernel builds
Date: Mon, 14 Sep 2026 19:25:28 +0100 [thread overview]
Message-ID: <aqg5nvRy9nuvC78L@gremlin> (raw)
In-Reply-To: <202609140833.88C0E16E50@keescook>
On Mon, Sep 14, 2026 at 08:41:39AM -0700, Kees Cook wrote:
> On Mon, Sep 14, 2026 at 10:21:59AM +0100, Lorenzo Stoakes (ARM) wrote:
> > This series makes allmodconfig builds up to 36% faster, ...
>
> This is very nice!
Thanks :)
>
> > incremental builds
> > up to ~70% faster, and noop builds up to ~90% faster.
>
> Some of the changes for this seem to add complexity that I'm not sure
> is balanced against the gain? I am still looking through the series,
> though, maybe I'll change my opinion. ;)
Well, I aggressively stripped all the commits that had a bad RoI on that.
And a lot of these are additive over 21 commits.
So, unfortunately, hacking away at what seem like low cost commits will eat
away at the overall result.
I really did work hard to cut the fat where I could, believe me going
through what remained and a. figuring out what it did, b. rewriting a lot
of the code and c. rewriting commit messages (ahem ;) was NOT fun :)
So I was happy to swing the axe as it saved me in terms of what little
sanity remains ;)
>
> > == allmodconfig FULL build ==
>
> Did you try Clang CONFIG_LTO=y builds?
I tried a CONFIG_LTO_CLANG_THIN in order to check that the *.mod.S stuff
worked correctly, all working correctly.
I can try to get some profiling numbers for thin and full if you want?
>
> > == LLM usage ==
> > [...]
> > I extensively audited and rewrote a lot of it, and heavily edited commit
> > messages, the cover letter and comments.
>
> I feel like the commit logs still need a lot of work. The LLM verbosity
> problem appears in many of them, for example spending 80% of the commit
Well I rewrote the majority of them, so this is a stinging critique of my
commit message writing I guess :)
> log describing every step of some process as background before getting
> to the actual change. I think a human writing this would be much more
> terse about the background. I have, however, been known to be too terse
> in my own commit logs. :P
I mean no, I did write nearly all of them. So I guess err... yeah :)
The testing results and perf numbers are generated and maybe I missed some
bits but generally this is so.
Anyway, I am known to be critical on-list on occasion, so if you dish it
out you have to take it - if you point out specific commit messages that
need work then I can try to put commit msgs on a diet :)
(N.B. I have had feedback like that on a fair few human-written commit
messages of mine lately so there might be some validity to that ;)
>
> > [...]
> > Nothing too controversial was included. There are further improvements that
> > could be made, but they would either by very invasive (large scale C header
> > changes) or generate diminishing returns.
>
> One area I think might solved via an LLM is the 3-pass kallsyms stuff.
> If we could get a deterministic kallsyms build in 1 pass, that would be
> very nice. A lot of people have tried, but it has eluded upstreaming.
"going from three passes to one would save around 8s on an allmodconfig
build and 2 to 3s on defconfig, out of tails that are currently roughly 25s
and 8s." says the LLM :) so that actually does seem worthwhile.
But I think best as a follow up?
I'd like to land the really low-hanging fruit before maybe digging in to
what else we can cut out :)
>
> -Kees
>
> --
> Kees Cook
--
Cheers, Lorenzo
_______________________________________________
linux-riscv mailing list
linux-riscv@lists.infradead.org
http://lists.infradead.org/mailman/listinfo/linux-riscv
next prev parent reply other threads:[~2026-09-14 18:25 UTC|newest]
Thread overview: 178+ messages / expand[flat|nested] mbox.gz Atom feed top
2026-09-14 9:21 [PATCH v2 00/21] kbuild: significantly speed up kernel builds Lorenzo Stoakes (ARM)
2026-09-14 9:21 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 01/21] kbuild: do not allocate .modinfo in vmlinux Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 02/21] kallsyms: index symbols by token to speed up table compression Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 03/21] kallsyms: output binary data to speed output and kallsyms assembly Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 20:16 ` Markus Elfring
2026-09-14 20:16 ` Markus Elfring
2026-09-14 21:44 ` David Laight
2026-09-14 21:44 ` David Laight
2026-09-15 7:10 ` [v2 " Markus Elfring
2026-09-15 7:10 ` Markus Elfring
2026-09-14 9:22 ` [PATCH v2 04/21] kbuild: do not sort nm output where the order is irrelevant Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 05/21] kbuild: only emit vmlinux relocations when required Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 06/21] elf-parse: add section flags, symbol binding and a read-only mapping Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 07/21] kallsyms: reimplement mksysmap in C Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 16:33 ` Markus Elfring
2026-09-14 16:33 ` Markus Elfring
2026-09-14 16:54 ` Markus Elfring
2026-09-14 16:54 ` Markus Elfring
2026-09-14 17:01 ` Markus Elfring
2026-09-14 17:01 ` Markus Elfring
2026-09-14 9:22 ` [PATCH v2 08/21] kbuild: cache list, composite object state per object Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 09/21] kbuild: implement and use depcheck to check dependency timestamps Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 10/21] kbuild: move the toolchain checks into init/Kconfig.toolchain Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 11/21] kbuild: avoid re-running compiler and linker probes Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 15:02 ` John Stoffel
2026-09-14 15:02 ` John Stoffel
2026-09-14 15:24 ` Lorenzo Stoakes (ARM)
2026-09-14 15:24 ` Lorenzo Stoakes (ARM)
2026-09-15 11:01 ` Lorenzo Stoakes (ARM)
2026-09-15 11:01 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 12/21] modpost: cache section relocation mismatch state Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 13/21] modpost: emit module descriptors as assembly Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-21 11:25 ` Petr Pavlu
2026-09-21 11:25 ` Petr Pavlu
2026-09-21 11:57 ` Lorenzo Stoakes (ARM)
2026-09-21 11:57 ` Lorenzo Stoakes (ARM)
2026-09-21 12:36 ` Petr Pavlu
2026-09-21 12:36 ` Petr Pavlu
2026-09-21 12:48 ` Lorenzo Stoakes (ARM)
2026-09-21 12:48 ` Lorenzo Stoakes (ARM)
2026-09-21 13:50 ` Petr Pavlu
2026-09-21 13:50 ` Petr Pavlu
2026-09-21 14:05 ` Lorenzo Stoakes (ARM)
2026-09-21 14:05 ` Lorenzo Stoakes (ARM)
2026-09-22 13:09 ` Lorenzo Stoakes (ARM)
2026-09-22 13:09 ` Lorenzo Stoakes (ARM)
2026-09-21 12:09 ` Jani Nikula
2026-09-21 12:09 ` Jani Nikula
2026-09-14 9:22 ` [PATCH v2 14/21] kbuild: batch module finalisation Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 18:00 ` Kees Cook
2026-09-14 18:00 ` Kees Cook
2026-09-15 10:44 ` Lorenzo Stoakes (ARM)
2026-09-15 10:44 ` Lorenzo Stoakes (ARM)
2026-09-15 16:49 ` Kees Cook
2026-09-15 16:49 ` Kees Cook
2026-09-15 17:54 ` Lorenzo Stoakes (ARM)
2026-09-15 17:54 ` Lorenzo Stoakes (ARM)
2026-09-15 17:56 ` Nick Desaulniers
2026-09-15 17:56 ` Nick Desaulniers
2026-09-16 14:30 ` Lorenzo Stoakes (ARM)
2026-09-16 14:30 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 15/21] objtool: cache relocations, do less work Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 19:44 ` Josh Poimboeuf
2026-09-14 19:44 ` Josh Poimboeuf
2026-09-14 20:06 ` Linus Torvalds
2026-09-14 20:06 ` Linus Torvalds
2026-09-14 22:23 ` Josh Poimboeuf
2026-09-14 22:23 ` Josh Poimboeuf
2026-09-14 22:30 ` Linus Torvalds
2026-09-14 22:30 ` Linus Torvalds
2026-09-15 12:24 ` Lorenzo Stoakes (ARM)
2026-09-15 12:24 ` Lorenzo Stoakes (ARM)
2026-09-15 12:19 ` Lorenzo Stoakes (ARM)
2026-09-15 12:19 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 16/21] objtool: size the instruction hash to the text Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 17/21] objtool: decode instructions and resolve branch targets in parallel Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 18:20 ` Kees Cook
2026-09-14 18:20 ` Kees Cook
2026-09-15 10:09 ` Lorenzo Stoakes (ARM)
2026-09-15 10:09 ` Lorenzo Stoakes (ARM)
2026-09-15 11:29 ` David Laight
2026-09-15 11:29 ` David Laight
2026-09-15 15:04 ` Lorenzo Stoakes (ARM)
2026-09-15 15:04 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 18/21] kbuild: rust: optionally parallelise rustc front end Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 18:32 ` Kees Cook
2026-09-14 18:32 ` Kees Cook
2026-09-15 11:09 ` Lorenzo Stoakes (ARM)
2026-09-15 11:09 ` Lorenzo Stoakes (ARM)
2026-09-15 11:16 ` Lorenzo Stoakes (ARM)
2026-09-15 11:16 ` Lorenzo Stoakes (ARM)
2026-09-15 6:32 ` Miguel Ojeda
2026-09-15 6:32 ` Miguel Ojeda
2026-09-15 11:15 ` Lorenzo Stoakes (ARM)
2026-09-15 11:15 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 19/21] rust: make exports.o depend on the headers generated for it Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 20/21] kbuild: build rust crates in parallel with the rest of the build Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 18:37 ` Kees Cook
2026-09-14 18:37 ` Kees Cook
2026-09-15 11:58 ` Lorenzo Stoakes (ARM)
2026-09-15 11:58 ` Lorenzo Stoakes (ARM)
2026-09-15 16:52 ` Kees Cook
2026-09-15 16:52 ` Kees Cook
2026-09-16 14:04 ` Lorenzo Stoakes (ARM)
2026-09-16 14:04 ` Lorenzo Stoakes (ARM)
2026-09-16 7:42 ` Gary Guo
2026-09-16 7:42 ` Gary Guo
2026-09-16 14:03 ` Lorenzo Stoakes (ARM)
2026-09-16 14:03 ` Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` [PATCH v2 21/21] kbuild: use pigz for gzip compression if available Lorenzo Stoakes (ARM)
2026-09-14 9:22 ` Lorenzo Stoakes (ARM)
2026-09-14 16:39 ` Kees Cook
2026-09-14 16:39 ` Kees Cook
2026-09-14 16:49 ` H. Peter Anvin
2026-09-14 16:49 ` H. Peter Anvin
2026-09-14 17:50 ` Kees Cook
2026-09-14 17:50 ` Kees Cook
2026-09-15 14:30 ` Lorenzo Stoakes (ARM)
2026-09-15 14:30 ` Lorenzo Stoakes (ARM)
2026-09-15 17:31 ` Kees Cook
2026-09-15 17:31 ` Kees Cook
2026-09-15 17:47 ` Nick Desaulniers
2026-09-15 17:47 ` Nick Desaulniers
2026-09-15 18:02 ` Arnd Bergmann
2026-09-15 18:02 ` Arnd Bergmann
2026-09-16 14:33 ` Lorenzo Stoakes (ARM)
2026-09-16 14:33 ` Lorenzo Stoakes (ARM)
2026-09-16 14:40 ` Lorenzo Stoakes (ARM)
2026-09-16 14:40 ` Lorenzo Stoakes (ARM)
2026-09-16 1:06 ` Kees Cook
2026-09-16 1:06 ` Kees Cook
2026-09-16 6:38 ` Arnd Bergmann
2026-09-16 6:38 ` Arnd Bergmann
2026-09-16 15:08 ` Lorenzo Stoakes (ARM)
2026-09-16 15:08 ` Lorenzo Stoakes (ARM)
2026-09-16 15:27 ` Kees Cook
2026-09-16 15:27 ` Kees Cook
2026-09-17 14:32 ` Lorenzo Stoakes (ARM)
2026-09-17 14:32 ` Lorenzo Stoakes (ARM)
2026-09-16 15:03 ` Lorenzo Stoakes (ARM)
2026-09-16 15:03 ` Lorenzo Stoakes (ARM)
2026-09-16 15:09 ` Kees Cook
2026-09-16 15:09 ` Kees Cook
2026-09-16 15:26 ` Lorenzo Stoakes (ARM)
2026-09-16 15:26 ` Lorenzo Stoakes (ARM)
2026-09-14 15:41 ` [PATCH v2 00/21] kbuild: significantly speed up kernel builds Kees Cook
2026-09-14 15:41 ` Kees Cook
2026-09-14 15:53 ` Linus Torvalds
2026-09-14 15:53 ` Linus Torvalds
2026-09-15 8:53 ` Arnd Bergmann
2026-09-15 8:53 ` Arnd Bergmann
2026-09-15 11:35 ` Lorenzo Stoakes (ARM)
2026-09-15 11:35 ` Lorenzo Stoakes (ARM)
2026-09-14 18:25 ` Lorenzo Stoakes (ARM) [this message]
2026-09-14 18:25 ` Lorenzo Stoakes (ARM)
2026-09-14 18:43 ` Kees Cook
2026-09-14 18:43 ` Kees Cook
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=aqg5nvRy9nuvC78L@gremlin \
--to=ljs@kernel.org \
--cc=a.hindborg@kernel.org \
--cc=acourbot@nvidia.com \
--cc=alex@ghiti.fr \
--cc=aliceryhl@google.com \
--cc=aou@eecs.berkeley.edu \
--cc=ardb@kernel.org \
--cc=arnd@arndb.de \
--cc=axboe@kernel.dk \
--cc=bjorn3_gh@protonmail.com \
--cc=boqun@kernel.org \
--cc=bp@alien8.de \
--cc=catalin.marinas@arm.com \
--cc=corbet@lwn.net \
--cc=dakr@kernel.org \
--cc=daniel.almeida@collabora.com \
--cc=dave.hansen@linux.intel.com \
--cc=gary@garyguo.net \
--cc=gustavoars@kernel.org \
--cc=hpa@zytor.com \
--cc=ilias.apalodimas@linaro.org \
--cc=jpoimboe@kernel.org \
--cc=justinstitt@google.com \
--cc=kees@kernel.org \
--cc=legion@kernel.org \
--cc=linux-arch@vger.kernel.org \
--cc=linux-arm-kernel@lists.infradead.org \
--cc=linux-doc@vger.kernel.org \
--cc=linux-efi@vger.kernel.org \
--cc=linux-hardening@vger.kernel.org \
--cc=linux-kbuild@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-riscv@lists.infradead.org \
--cc=llvm@lists.linux.dev \
--cc=lossin@kernel.org \
--cc=mark.rutland@arm.com \
--cc=masahiroy@kernel.org \
--cc=mingo@redhat.com \
--cc=morbo@google.com \
--cc=nathan@kernel.org \
--cc=ndesaulniers@google.com \
--cc=nsc@kernel.org \
--cc=ojeda@kernel.org \
--cc=palmer@dabbelt.com \
--cc=peterz@infradead.org \
--cc=pjw@kernel.org \
--cc=rdunlap@infradead.org \
--cc=rust-for-linux@vger.kernel.org \
--cc=tamird@kernel.org \
--cc=tglx@kernel.org \
--cc=tmgross@umich.edu \
--cc=torvalds@linux-foundation.org \
--cc=will@kernel.org \
--cc=work@onurozkan.dev \
--cc=x86@kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.